==> ckeditor_responsive_table-1.0.2.tar.gz: ckeditor_responsive_table/src/Form/CkeditorResponsiveTableForm.php <==
<?php

/**
 * @file
 * Contains Drupal\ckeditor_responsive_table\Form\CkeditorResponsiveTableForm.
 */

namespace Drupal\ckeditor_responsive_table\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class CkeditorResponsiveTableForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ckeditor_responsive_table_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Form constructor.
    $form = parent::buildForm($form, $form_state);
    // Default settings.
    $config = $this->config('ckeditor_responsive_table.settings');
    $default_value = $config->get('ckeditor_responsive_table.table_selector');
    if (empty($default_value)) {
      $default_value = $config->get('default_table_selector');
    }

    // Source text field.
    $form['table_selector'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Table selector'),
      '#default_value' => $default_value,
      '#description' => $this->t('Enter a CSS selector to apply the responsive table script to.'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('ckeditor_responsive_table.settings');
    $config->set('ckeditor_responsive_table.table_selector', $form_state->getValue('table_selector'));
    $config->save();
    return parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'ckeditor_responsive_table.settings',
    ];
  }

}

==> ckeditor_responsive_table-1.0.4.tar.gz: ckeditor_responsive_table/src/Form/CkeditorResponsiveTableForm.php <==
<?php

/**
 * @file
 * Contains Drupal\ckeditor_responsive_table\Form\CkeditorResponsiveTableForm.
 */

namespace Drupal\ckeditor_responsive_table\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class CkeditorResponsiveTableForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ckeditor_responsive_table_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Form constructor.
    $form = parent::buildForm($form, $form_state);
    // Default settings.
    $config = $this->config('ckeditor_responsive_table.settings');
    $default_value = $config->get('table_selector');
    if (empty($default_value)) {
      $default_value = $config->get('default_table_selector');
    }

    // Source text field.
    $form['table_selector'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Table selector'),
      '#default_value' => $default_value,
      '#description' => $this->t('Enter a CSS selector to apply the responsive table script to.'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('ckeditor_responsive_table.settings');
    $config->set('table_selector', $form_state->getValue('table_selector'));
    $config->save();
    return parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'ckeditor_responsive_table.settings',
    ];
  }

}
